@@ -266,7 +266,7 @@ class EmbeddingsProvider:
             # (typically self.max_length == 77)
             chunk_token_ids = [self.tokenizer.bos_token_id] + chunk_token_ids + [self.tokenizer.eos_token_id]
             chunk_token_weights = [1.0] + chunk_token_weights + [1.0]
-            chunk_mask = [1.0] * len(chunk_token_ids)
+            chunk_mask = [1] * len(chunk_token_ids)
 
             pad_length = self.max_token_count - len(chunk_token_ids)
             chunk_token_ids += [self.tokenizer.pad_token_id] * pad_length
@@ -359,7 +359,6 @@ class EmbeddingsProvider:
         for fragment_index, fragment_token_ids in enumerate(per_fragment_token_ids):
             if len(fragment_token_ids) == 0:
                 corresponding_indices.append((None, None))
-                fragment_start += 1
                 continue
             if self.truncate_to_model_max_length and fragment_start >= self.tokenizer.model_max_length - 1:
                 break
