@@ -496,8 +496,9 @@ def build_parser_syntax(attention_plus_base: float, attention_minus_base: float)
 
     # a word that absolutely does not contain any meaningful syntax
     non_syntax_word = pp.Combine(pp.OneOrMore(pp.MatchFirst([
-            pp.Or(syntactic_symbols.values()),
+            pp.Or(syntactic_symbols.values()), # escaped syntactic symbols
             pp.one_of(['-', '+']) + pp.NotAny(pp.White() | pp.Char(syntactic_chars) | pp.StringEnd()),
+            number,
             # build character-by-character
             pp.CharsNotIn(string.whitespace + syntactic_chars, exact=1)
         ])))
@@ -592,9 +593,11 @@ def build_parser_syntax(attention_plus_base: float, attention_minus_base: float)
     cross_attention_substitute.set_debug(False)
     cross_attention_substitute.set_parse_action(make_operator_object)
 
-    lora_weight = "withLora" + lparen + keyword + pp.Optional(comma + number) + rparen
-    lora_weight.set_name('lora_weight')
-    lora_weight.set_parse_action(lambda x: LoraWeight(model=x[1], weight=x[2]))
+    lora_weight = ("withLora" + lparen + keyword +
+                   pp.Optional(comma + number).set_name('lora_weight').set_debug(False)
+                   + rparen)
+    lora_weight.set_name('lora').set_debug(False)
+    lora_weight.set_parse_action(lambda x: LoraWeight(model=x[1], weight=(x[2] if len(x) > 2 else 1)))
 
     # an entire self-contained prompt, which can be used in a Blend or Conjunction
     prompt = pp.ZeroOrMore(pp.MatchFirst([
